==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/vi-VN/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Giới thiệu về Địa điểm',
    'about_locations'           => 'Vị trí được sử dụng để theo dõi thông tin vị trí cho người dùng, nội dung và các mục khác',
    'assets_rtd'                => 'Tài sản', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Assets Assigned',
    'id'                        => 'ID',
    'city'                      => 'Thành phố',
    'state'                     => 'Tỉnh/Thành phố',
    'country'                   => 'Nước',
    'create'                    => 'Tạo địa phương',
    'update'                    => 'Cập nhật địa phương',
    'print_assigned'            => 'In tài sản đã cấp phát',
    'print_all_assigned'        => 'In tất cả tài sản đã cấp phát',
    'name'                      => 'Tên địa phương',
    'address'                   => 'Địa chỉ',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'Mã bưu điện',
    'locations'                 => 'Địa phương',
    'parent'                    => 'Parent',
    'currency'                  => 'Tiền tệ địa phương',
    'ldap_ou'                   => 'Tìm kiếm LDAP của OU',
    'user_name'                 => 'Tài khoản',
    'department'                => 'Bộ phận',
    'location'                  => 'Vị trí',
    'asset_tag'                 => 'Thẻ tài sản',
    'asset_name'                => 'Tên',
    'asset_category'            => 'Danh mục',
    'asset_manufacturer'        => 'Nhà sản xuất',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Số Sê-ri',
    'asset_location'            => 'Vị trí',
    'asset_checked_out'         => 'Bàn giao',
    'asset_expected_checkin'    => 'Ngày mong muốn Thu hồi',
    'date'                      => 'Ngày:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Được ký bởi (Quản lý kiểm kê):',
    'signed_by_finance_auditor' => 'Được ký bởi (Quản lý tài chính):',
    'signed_by_location_manager' => 'Được ký bởi (Quản lý khu vực):',
    'signed_by'                 => 'Được ký bởi:',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/vi-VN/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Giới thiệu về Địa điểm',
    'about_locations'           => 'Vị trí được sử dụng để theo dõi thông tin vị trí cho người dùng, nội dung và các mục khác',
    'assets_rtd'                => 'Tài sản', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Assets Assigned',
    'id'                        => 'ID',
    'city'                      => 'Thành phố',
    'state'                     => 'Tỉnh/Thành phố',
    'country'                   => 'Nước',
    'create'                    => 'Tạo địa phương',
    'update'                    => 'Cập nhật địa phương',
    'print_assigned'            => 'In tài sản đã cấp phát',
    'print_all_assigned'        => 'In tất cả tài sản đã cấp phát',
    'name'                      => 'Tên địa phương',
    'address'                   => 'Địa chỉ',
    'address2'                   => 'Địa chỉ thứ 2',
    'zip'                       => 'Mã bưu điện',
    'locations'                 => 'Địa phương',
    'parent'                    => 'Parent',
    'currency'                  => 'Tiền tệ địa phương',
    'ldap_ou'                   => 'Tìm kiếm LDAP của OU',
    'user_name'                 => 'Tài khoản',
    'department'                => 'Bộ phận',
    'location'                  => 'Vị trí',
    'asset_tag'                 => 'Thẻ tài sản',
    'asset_name'                => 'Tên',
    'asset_category'            => 'Danh mục',
    'asset_manufacturer'        => 'Nhà sản xuất',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Số Sê-ri',
    'asset_location'            => 'Vị trí',
    'asset_checked_out'         => 'Bàn giao',
    'asset_expected_checkin'    => 'Ngày mong muốn Thu hồi',
    'date'                      => 'Ngày:',
    'phone'                     => 'Số điện thoại',
    'signed_by_asset_auditor'   => 'Được ký bởi (Quản lý kiểm kê):',
    'signed_by_finance_auditor' => 'Được ký bởi (Quản lý tài chính):',
    'signed_by_location_manager' => 'Được ký bởi (Quản lý khu vực):',
    'signed_by'                 => 'Được ký bởi:',
];
